## Timeline

- November 2023 : initial public release for bioRxiv paper
- January 2024 : major changes for user interface, reproducibility, and future development
 - Simplified YAML files
 - Simplified some `*.smk` files
 - Published the isweep package to PyPI
 <!-- - Removed some developer comments -->
 - Tested against results in November 2023 release
- July 2024 : documentation, small bug fixes
 - Vignettes, especially for required sample size 
 - More flexibility in selection modeling
 - Python script to summarize ROI outputs
 <!-- - Multiple testing correction -->